@@ -31,8 +31,6 @@ import dill
 from multiprocessing import Pool
 from itertools import product
 from time import time
-import scipy
-from scipy.optimize import minimize
 import warnings
 from contextlib import closing
 from tqdm import tqdm
@@ -851,6 +849,8 @@ def __min__(ii):
 
     :param ii: index of data pixel
     """
+    from scipy.optimize import minimize  # import here to avoid static TLS ImportError
+
     i1, i2 = ii
 
     ress_full = minimize(fun=__forward__, x0=__xa__[i1, i2, :], args=(__pt__[i1, i2, :], __data__[i1, i2, :]),
@@ -872,6 +872,8 @@ def __min_ice__(ii):
 
     :param ii: index of data pixel
     """
+    from scipy.optimize import minimize  # import here to avoid static TLS ImportError
+
     i1, i2 = ii
 
     ress_full = minimize(fun=__forward__, x0=__xa__[i1, i2, :], args=(__pt__[i1, i2, :], __data__[i1, i2, :]),
@@ -894,10 +896,12 @@ def __oe__(ii):
 
     :param ii: index of data pixel
     """
+    from scipy import sqrt  # import here to avoid static TLS ImportError
+
     i1, i2 = ii
 
     if __instrument__ == "AVIRIS":
-        nedl = abs(__snr__[:, 0] * scipy.sqrt(__snr__[:, 1] + __data__[i1, i2, :]) + __snr__[:, 2])
+        nedl = abs(__snr__[:, 0] * sqrt(__snr__[:, 1] + __data__[i1, i2, :]) + __snr__[:, 2])
         se = np.identity(len(__fit_wvl__)) * nedl
     else:
         se = np.identity(len(__fit_wvl__)) * ((__data__[i1, i2, :] / __snr__) ** 2)
@@ -944,10 +948,12 @@ def __oe_ice__(ii):
 
     :param ii: index of data pixel
     """
+    from scipy import sqrt  # import here to avoid static TLS ImportError
+
     i1, i2 = ii
 
     if __instrument__ == "AVIRIS":
-        nedl = abs(__snr__[:, 0] * scipy.sqrt(__snr__[:, 1] + __data__[i1, i2, :]) + __snr__[:, 2])
+        nedl = abs(__snr__[:, 0] * sqrt(__snr__[:, 1] + __data__[i1, i2, :]) + __snr__[:, 2])
         se = np.identity(len(__fit_wvl__)) * nedl
     else:
         se = np.identity(len(__fit_wvl__)) * ((__data__[i1, i2, :] / __snr__) ** 2)
